#!/bin/sh
###########################################################################
#                                                                         #
#                                                                         #
#              Copyright (c) 2008 Iskratel                                #
#                                                                         #
#                                                                         #
#   Name        : ncfm_conf.sh                                            #
#                                                                         #
#   Description : Set operating system configuration files                #
#                 (for linux products)                                    #
#                                                                         #
#   Position    : $RTE_DIR/system/ncfm/                                   #
#                                                                         #
#   Code        : QQQK                                                    #
#                                                                         #
#   Date        : may 2009                                                #
#                                                                         #
#   Author      : Andrej Oblak, ITRDD1                                    #
#                                                                         #
#   Translation : * None                                                  #
#                                                                         #
###########################################################################

#All global variables are written with UPPER CAPITALS and are formatet like:
# letter an underscore - example: G_RV - gloval return value
# meaning of first leters:
# G_   -   global
# F_   -   files
# D_   -   direcroty
# DG_  -   debug
# X_   -   executable
# E_   -   error
# C_   -   linux configuration file
# STR_ -   parsing strings


#####################
# DEBUGGING PURPOSE #
#####################
DG_DEBUG=0
if [ "$DG_DEBUG" -eq "1" ]
then
  F_DEBUGFILE=/tmp/ncfm.log
  echo "`basename $0` at `date`" >> $F_DEBUGFILE
else
  F_DEBUGFILE=/dev/null
fi
F_DEBUGFILE_BACKUP=$F_DEBUGFILE

F_ERR_FILE=/tmp/ncfm.err

################
# Executables  #
################
# prefix: X_ identifies executables
#we don't need to check command which, cause first check will fail if which does not exists
#X_global_used_cmds="sed awk grep cat mv echo route vconfig ip wc inetd basename"

#we use which before testing if which exists, but our further test will fail if which does not exists,
#cause our wariable will have wrong value

X_WHICH=`which which`
X_WC=`which wc`
X_PS=`which ps`
X_SED=`which sed`
#X_AWK=`which awk`
X_GREP=`which grep`
X_CAT=`which cat`
X_MV=`which mv`
X_RM=`which rm`
X_CP=`which cp`
X_MKDIR=`which mkdir`
X_ECHO=`which echo`
#X_ROUTE=`which route`
X_VCONFIG=`which vconfig`
X_IP=`which ip`
#X_INETD=/etc/init.d/inetd
X_BASENAME=`which basename`
X_LN=`which ln`
X_HOSTNAME=`which hostname`
X_IPMICLI=/opt/iskratel/sbin/ipmiCli
#X_FIND=`which find`
#X_RDATE=`which rdate`
#X_HWCLOCK=`which hwclock`
#X_TEE=`which tee` #read from standard input and write to standard output and files

#executable services
X_NIESUBAG=/etc/init.d/niesubag


X_global_used_cmds=`echo $X_WHICH $X_SED $X_RM $X_MKDIR $X_ECHO`



###############################
# MODULE GLOBAL CONFIGURATION #
###############################

########################
# GLOBAL RETURN VALUES #
########################
# prefix: E_ identifies error
#to systematize exit status numbers we refered to /usr/include/sysexits.h
OK=0
E_ERROR=1               #general errors - we avoid to use this
E_BAD_ARGS=64           #command line usage error
E_SERVICE_ERROR=69      #service error - maybe it is not running
E_INTERNAL=70           #internal software error - should never happen
E_FILE_SYSTEM_ERROR=72  #critical OS file missing


####################
# Global variables #
####################
G_ARGS_NUM=2
G_AVAILABLE_ACTIONS_LONG="help create set insert update delete get attach-ip update-ip delete-ip up down"
G_AVAILABLE_ACTIONS="-C -S -I -U -D -G -Aip -Uip -Dip -up -do "$G_AVAILABLE_ACTIONS_LONG

#AN
G_ENABLED_OBJECTS="hosts host-name interface route ipmi-board-pos snmp-trap-tos time-zone"
#MG
#G_ENABLED_OBJECTS="snmp-trap-tos"
G_TMP_DIR=/dev/shm/ncfm/     #by default tmp direcroty is "RAM" drive
G_RESTART_RETIES=4      #with this variable we can actualy disable of restarting all services if we set it to zero
G_PRINT_USAGE_ON_EXIT=1 #should be 1 if we want usage to be printed out if error occured
G_TMP_VAR1=$E_ERROR     #temporary variable 1
G_BACKUP_FILES=""       #list of backup files separated by space - if NCFM detects an error already changed files will be restored. List must be EVEN number! Fist you specifie a file that is ok and then a file that needs to be replaced! - default: empty

###################
# Parsing strings #
###################
STR_SNMPTRAPTOS=tos_udp
STR_SNMPTRAPTOSCATEGORY=general

#######################
# System config files #
#######################
# prefix: C_ identifies configuration file
C_HOSTS=/etc/hosts
C_HOSTS_TMP=${G_TMP_DIR}etc_hosts

C_HOSTNAME=/etc/hostname
C_HOSTNAME_TMP=${G_TMP_DIR}etc_hostname

C_NIESUBAGENT=/opt/iskratel/bin/niesubag.ini
C_NIESUBAGENT_TMP=${G_TMP_DIR}niesubag_ini

C_NTP=/etc/ntp.conf
C_NTP_TMP=${G_TMP_DIR}etc_ntp_conf


C_LOCALTIME=/etc/localtime #it is only a simbolic link. It don't need to be writable and also if it does not exists, we will create it
D_ZONEINFO=/usr/share/zoneinfo/ #don't need to be writable

#we never include TMP configuration files in to a check (we don't add them in variable C_global_used_confs)
C_global_used_confs=`echo `
C_auto_create_if_needed=`echo $C_HOSTNAME`
