#!/bin/sh
###########################################################################
#                                                                         #
#                                                                         #
#              Copyright (c) 2008 Iskratel                                #
#                                                                         #
#                                                                         #
#   Name        : ncfm.sh                                                 #
#                                                                         #
#   Description : Set operating system configuration files                #
#                 (for linux products)                                    #
#                                                                         #
#   Position    : $RTE_DIR/system/ncfm/                                   #
#                                                                         #
#   Code        : QQQJ                                                    #
#                                                                         #
#   Date        : may 2009                                                #
#                                                                         #
#   Author      : Andrej Oblak, ITRDD1                                    #
#                                                                         #
#   Returns     : 0 = script execution was successfull                    #
#                 1 - 255 = script execution failed                       #
#                                                                         #
#   Translation : * None                                                  #
#                                                                         #
#   Revisions   : 3.5.2009 Andrej Oblak, ITRDD1                           #
#                 Initial release                                         #
#                                                                         #
###########################################################################
#set -x
#All global variables are written with UPPER CAPITALS and are formatet like:
# letter an underscore - example: G_RV - gloval return value
# meaning of first leters:
# G_   -   global
# F_   -   files
# D_   -   direcroty
# DG_  -   debug
# X_   -   executable
# E_   -   error
# C_   -   linux configuration file
# STR_ -   parsing strings


#####################
# DEBUGGING PURPOSE #
#####################
#debugging before configuration file. If you want to use debugging when configuration file is already loaded, you should set debug in configuration file
F_DEBUGFILE=/dev/null

########################
# GLOBAL CONFIGURATION #
########################
D_MODULE_SH_DIR=/opt/iskratel/sbin/
D_MODULE_CONF_DIR=/opt/iskratel/etc/
D_PRODUCT_CONF_DIR=/opt/si2000/neroot/active/etc/

F_FUNC_FILE=${D_MODULE_SH_DIR}ncfm_func.sh
F_CONF_FILE=${D_MODULE_CONF_DIR}ncfm_conf.sh
F_PROD_CONF_FILE=${D_PRODUCT_CONF_DIR}ncfm_pconf.sh

########################
# GLOBAL RETURN VALUES #
########################
E_NO_FUNC_FILE=79
E_NO_CONF_FILE=80


#####################################################################################
#**************************  I M P L E M E N T A T I O N  **************************#
#####################################################################################

#######################
# Load functions file #
#######################
if [ -f "$F_FUNC_FILE" ]
then
  . $F_FUNC_FILE
else
  echo "No function file: $F_FUNC_FILE"
  echo "No function file: $F_FUNC_FILE" >> $F_DEBUGFILE
  exit $E_NO_FUNC_FILE
fi

#ncfm_set_debug /dev/console
#ncfm_set_debug /dev/pts/0
#ncfm_set_debug /dev/ttyp0
####################
# GLOBAL VARIABLES #
####################
G_RV=E_ERROR; #gloval return value: return of every function, but exit_on_error must be called
G_INTERFACE_NAME="" #interface name we work on - this is used by function ncfm_get_real_interface_name
G_TMP="" #temp global variable

$X_ECHO "cli args: $@" >> $F_DEBUGFILE

###################################
# Chech number of input arguments #
###################################
if [ "$#" -lt "$G_ARGS_NUM" ]||[ "$1" == "-h" ]||[ "$1" == "--help" ]
then
  ncfm_usage
  exit $E_BAD_ARGS
fi

###############################################
# Global executables check of the file system #
###############################################

ncfm_check_fs $X_global_used_cmds
ncfm_exit_on_error "ncfm_check_fs failed"

#######################################################
# Global configuration files check of the file system #
#######################################################

ncfm_check_confs $C_global_used_confs
ncfm_exit_on_error "ncfm_check_confs failed"

##########################
# Initialization of NCFM #
##########################
ncfm_init
ncfm_exit_on_error "ncfm_init failed"

#########################
# Read input parameters #
#########################
ncfm_read_params $@
ncfm_exit_on_error "ncfm_read_params failed"




#******************************#
# per OBJECT file system check #
#******************************#

#############################################
# Selective chech number of input arguments #
#############################################
ncfm_selective_arg_chk $@
ncfm_exit_on_error "ncfm_selective_arg_chk failed"

##################################################
# Selective executables check of the file system #
##################################################

ncfm_selective_check_fs
ncfm_exit_on_error "ncfm_check_fs failed"

##########################################################
# Selective configuration files check of the file system #
##########################################################

ncfm_selective_check_confs
ncfm_exit_on_error "ncfm_check_confs failed"


#####################
# MAIN IMPLEMANTION #
#####################

case "$G_NCFM_OBJECT" in

  hosts)
    ncfm_hosts
    ncfm_exit_on_error "ncfm_hosts failed"
    ;;

  host-name)
    ncfm_host_name
    ncfm_exit_on_error "ncfm_host_name failed"
    ;;

  interface)
    ncfm_interface
    ncfm_exit_on_error "ncfm_interface failed"
    ;;

  route)
    ncfm_route
    ncfm_exit_on_error "ncfm_route failed"
    ;;

  ipmi-board-pos)
    ncfm_ipmi_board_pos
    ncfm_exit_on_error "ncfm_ipmi_board_pos failed"
    ;;

  snmp-trap-tos)
    ncfm_snmp_trap_tos
    ncfm_exit_on_error "ncfm_snmp_trap_tos failed"
    ;;

  time-zone)
    ncfm_time_zone
    ncfm_exit_on_error "ncfm_time_zone failed"
    ;;

  *)#default
    ncfm_printErr "Wrong OBJECT"
    ncfm_usage
    exit $E_BAD_ARGS
    ;;

esac #end case


###################
# Destroy of NCFM #
###################
ncfm_destroy


ncfm_printf "ncfm.sh successfully finished"
exit $OK
